import React, { useState, useEffect } from 'react';
import { Button, Table, Pagination } from 'antd';
import moment from 'moment';
import apis from '../../../../services/apis';
import request from '../../../../utils/request';
import AuthButton from '../../../../components/AuthButton';

const table = props => {
    const { id, type } = props
    const [data, setData] = useState([])


    useEffect(() => {
        // console.log(activityId, activityType)
        getList({ pageNum: 1, pageSize: 10, qrCodeId: id, type })

    }, [type])

    const getList = params => {
        // console.log(params)
        request({ ...apis.qrcode.getStatisticRecord, params: { ...params } }).then(data => {
            console.log(data)

            setData(data)
        }).catch(e => {
            console.log(e)
        })
    }

    const visitNum = {
        title: '访问时间',
        dataIndex: 'visitDate',
        key: 'visitDate',
        render: (x, row) => <><span>{`${moment(row.visitDate).format('YYYY-MM-DD HH:mm:ss')}`}</span></>,
    }

    const visitors = {
        title: '访问次数',
        dataIndex: 'visitNum',
        key: 'visitNum',
    }

    const newuser = {
        title: '注册时间',
        dataIndex: 'visitDate',
        key: 'visitDate',
        render: (x, row) => <><span>{`${moment(row.visitDate).format('YYYY-MM-DD HH:mm:ss')}`}</span></>,
    }

    const columns = [
        {
            title: '姓名',
            dataIndex: 'nickName',
            key: 'nickName',
        },
        {
            title: '电话',
            dataIndex: 'phone',
            key: 'phone',
        },
        {
            title: '性别',
            dataIndex: 'gender',
            key: 'gender',
        },
        {
            title: '归属地',
            dataIndex: 'province',
            key: 'province',
        },
        // eslint-disable-next-line no-nested-ternary
        type === '1' ? visitors : type === '2' ? visitNum : newuser,
    ]


    const changePageNum = pageNumber => {
        getList({ pageNum: pageNumber, pageSize: 10 })
    }

    // 下载文档
    function download(data) {
        if (!data) {
            console.log('234')
            return
        }
        const url = window.URL.createObjectURL(new Blob([data]))
        const link = document.createElement('a')
        link.style.display = 'none'
        link.href = url
        if (type === 1) {
            link.setAttribute('download', '访问人数.xlsx')
        } else if (type === 2) {
            link.setAttribute('download', '访问次数.xlsx')
        } else {
            link.setAttribute('download', '新增注册用户.xlsx')
        }

        document.body.append(link)
        link.click()
    }

    const exportStatisticRecord = () => {

        request({ ...apis.qrcode.getStatisticRecordExport, responseType: 'blob', params: { qrCodeId: id, type } }).then(data => {
            console.log(data, '22222222')
            download(data)

            // const url = window.URL.createObjectURL(new Blob([data]))responseType: 'blob',
            // const link = document.createElement('a')
            // link.style.display = 'none'
            // link.href = url
            // link.setAttribute('download', '访问统计.xlsx')
            // document.body.append(link)
            // link.click()
        }).catch((err) => {
            console.log(err, '3333333333')
        })
        //   const url = window.URL.createObjectURL(new Blob([data]))
        //   const link = document.createElement('a')
        //   link.style.display = 'none'
        //   link.href = url
        //   link.setAttribute('download', '访问统计.xlsx')
        //   document.body.append(link)
        //   link.click()
        // }).catch()
    }

    return <>
        <div>
            <div>


                <Button type="primary" style={{ float: 'right', marginBottom: '20px', zIndex: 1 }} onClick={exportStatisticRecord} >
                    导出
            </Button>

            </div>
            <Table style={{ marginTop: '30px' }} dataSource={data.records} columns={columns} pagination={false} rowKey="activityList" />
            <div style={{ display: 'flex', justifyContent: 'flex-end', marginTop: '30px' }}>
                <Pagination showQuickJumper defaultCurrent={1} total={data.total} onChange={changePageNum} current={data.current} />
            </div>
        </div>
    </>
}

export default table